@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: init.cc,v 1.2 2002/04/14 15:14:28 murrayc Exp $ */
+/* $Id: init.cc 1556 2008-06-10 11:11:02Z jhs $ */
 
 /* init.cc
  *
@@ -21,17 +21,25 @@
  */
 
 #include <libgdamm/init.h>
-#include <gtkmm/wrap_init.h>
+#include <glibmm/init.h>
 #include <libgdammconfig.h> //For LIBGDAMM_VERSION
 #include <libgdamm/wrap_init.h>
 #include <libgda/libgda.h>
 
+
 namespace Gnome
 {
 
 namespace Gda
 {
 
+void init()
+{
+  Glib::init(); //Sets up the g type system and the Glib::wrap() table.
+  wrap_init(); //Tells the Glib::wrap() table about the libgnomecanvasmm classes.
+  gda_init();
+}
+
 
 } //namespace Gda
 } //namespace Gnome
