@@ -1,4 +1,4 @@
-/* $Id: value.cc 1059 2007-03-30 13:40:09Z arminb $ */
+/* $Id: value.cc 1760 2008-11-01 09:15:20Z jhs $ */
 // -*- C++ -*- //
 
 /* value.cc
@@ -122,6 +122,11 @@ Value::Value(gushort val)
   set(val);
 }
 
+Value::Value(gulong val)
+{
+  set(val);
+}
+
 Value::Value(const Glib::ustring& val)
 {
   set(val);
@@ -317,7 +322,8 @@ Glib::Date Value::get_date() const
 
 void Value::set(const Glib::Date& val)
 {
-  value_reinit(gobj(), Glib::Value<Glib::Date>::value_type());
+  //There is no Glib::Value<> specialization, so we explicitly mention G_TYPE_DATE: value_reinit(gobj(), Glib::Value<Glib::Date>::value_type());
+  value_reinit(gobj(), G_TYPE_DATE);
   g_value_set_boxed(gobj(), val.gobj());
 }
 
@@ -370,7 +376,7 @@ const GdaNumeric* Value::get_numeric() const
 
 void Value::set(const GdaNumeric * val)
 {
-  gda_value_set_numeric(gobj(), val); 
+  gda_value_set_numeric(gobj(), val);
 }
 
 float Value::get_float() const
@@ -404,6 +410,16 @@ void Value::set(gushort val)
   gda_value_set_ushort(gobj(), val); 
 }
 
+gulong Value::get_ulong() const
+{
+  return g_value_get_ulong(const_cast<GValue*>(gobj()));
+}
+
+void Value::set(gulong val)
+{
+  g_value_set_ulong(gobj(), val); 
+}
+
 Glib::ustring Value::get_string() const
 {
   return Glib::convert_const_gchar_ptr_to_ustring(g_value_get_string(const_cast<GValue*>(gobj())));
@@ -456,7 +472,7 @@ GType Value::get_g_type() const
   return g_value_get_gtype(gobj());
 }
 
-void Value::set(GType val)
+void Value::set_g_type(GType val)
 {
   value_reinit(gobj(), G_TYPE_GTYPE);
   g_value_set_gtype(gobj(), val);
