@@ -3,7 +3,7 @@
 #define _LIBGDAMM_VALUE_H
 
 
-/* $Id: value.h 1760 2008-11-01 09:15:20Z jhs $ */
+/* $Id: value.h 1839 2008-12-12 11:39:11Z murrayc $ */
 // -*- C++ -*- //
 
 /* value.h
@@ -248,7 +248,7 @@ struct ValueTraits
   static CType to_c_type(const CppType& obj) { return obj.gobj(); }
   static CType to_c_type(const CType& obj) { return obj; }
   static CppType to_cpp_type(const CType& obj) { return CppType(obj); }
-  static void release_c_type(const CType& obj) {}
+  static void release_c_type(const CType& /*obj*/) {}
 };
 #endif
 
