@@ -39,7 +39,6 @@
 #include "metastore.h"
 #include "metastruct.h"
 #include "config.h"
-#include "threader.h"
 #include "blobop.h"
 #include "blob.h"
 #include "quarklist.h"
@@ -82,7 +81,6 @@ GType gda_server_provider_get_type(void);
 GType gda_set_get_type(void);
 GType gda_sql_parser_get_type(void);
 GType gda_statement_get_type(void);
-GType gda_threader_get_type(void);
 GType gda_transaction_status_get_type(void);
 GType gda_xa_transaction_get_type(void);
 
@@ -124,7 +122,6 @@ namespace Gnome { namespace Gda {  class ServerProvider_Class { public: static G
 namespace Gnome { namespace Gda {  class Set_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class SqlParser_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class Statement_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
-namespace Gnome { namespace Gda {  class Threader_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class TransactionStatus_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class XaTransaction_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 
@@ -166,7 +163,6 @@ void wrap_init()
   Glib::wrap_register(gda_set_get_type(), &Gnome::Gda::Set_Class::wrap_new);
   Glib::wrap_register(gda_sql_parser_get_type(), &Gnome::Gda::SqlParser_Class::wrap_new);
   Glib::wrap_register(gda_statement_get_type(), &Gnome::Gda::Statement_Class::wrap_new);
-  Glib::wrap_register(gda_threader_get_type(), &Gnome::Gda::Threader_Class::wrap_new);
   Glib::wrap_register(gda_transaction_status_get_type(), &Gnome::Gda::TransactionStatus_Class::wrap_new);
   Glib::wrap_register(gda_xa_transaction_get_type(), &Gnome::Gda::XaTransaction_Class::wrap_new);
 
@@ -199,7 +195,6 @@ void wrap_init()
   Gnome::Gda::Set::get_type();
   Gnome::Gda::SqlParser::get_type();
   Gnome::Gda::Statement::get_type();
-  Gnome::Gda::Threader::get_type();
   Gnome::Gda::TransactionStatus::get_type();
   Gnome::Gda::XaTransaction::get_type();
 
